================================
MicroService framework :: Schema
================================

.. image:: https://travis-ci.org/palankai/pyrs-schema.svg?branch=master
       :target: https://travis-ci.org/palankai/pyrs-schema

.. image:: https://coveralls.io/repos/palankai/pyrs-schema/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/palankai/pyrs-schema?branch=master

.. image:: https://readthedocs.org/projects/pyrs-schema/badge/?version=stable
   :target: http://pyrs-schema.readthedocs.org/en/stable/
   :alt: Documentation Status

Project hompage: `<https://github.com/palankai/pyrs-schema>`_

Documentation: `<http://pyrs-schema.readthedocs.org/>`_

This package implement the schema part.
Schame provides primitive and complex types, validation based on that and also
provide flexible and extensible API for serialisation.
